#[non_exhaustive]pub struct HyperparameterSource {
pub source_engine_config: String,
pub source_engine_version: String,
/* private fields */
}Expand description
Parameters for bootstrapping an Engine Config with the results of another one.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_engine_config: StringRequired. The resource name of the source EngineConfig whose outputs are
used. Format:
/projects/{project_num}/locations/{location}/instances/{instance}/engineConfigs/{engine_config}
source_engine_version: StringOutput only. The resource name of the EngineVersion that was used in the
tuning run. Format:
/projects/{project_num}/locations/{location}/instances/{instance}/engineVersions/{engine_version}
Implementations
Sourceimpl HyperparameterSource
impl HyperparameterSource
Sourcepub fn set_source_engine_config<T: Into<String>>(self, v: T) -> Self
pub fn set_source_engine_config<T: Into<String>>(self, v: T) -> Self
Sets the value of source_engine_config.
Example
ⓘ
let x = HyperparameterSource::new().set_source_engine_config("example");Sourcepub fn set_source_engine_version<T: Into<String>>(self, v: T) -> Self
pub fn set_source_engine_version<T: Into<String>>(self, v: T) -> Self
Sets the value of source_engine_version.
Example
ⓘ
let x = HyperparameterSource::new().set_source_engine_version("example");Trait Implementations
Sourceimpl Clone for HyperparameterSource
impl Clone for HyperparameterSource
Sourcefn clone(&self) -> HyperparameterSource
fn clone(&self) -> HyperparameterSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HyperparameterSource
impl Debug for HyperparameterSource
Sourceimpl Default for HyperparameterSource
impl Default for HyperparameterSource
Sourcefn default() -> HyperparameterSource
fn default() -> HyperparameterSource
Returns the “default value” for a type. Read more
Sourceimpl Message for HyperparameterSource
impl Message for HyperparameterSource
Sourceimpl PartialEq for HyperparameterSource
impl PartialEq for HyperparameterSource
Sourcefn eq(&self, other: &HyperparameterSource) -> bool
fn eq(&self, other: &HyperparameterSource) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HyperparameterSource