PerformanceTarget

Struct PerformanceTarget 

#[non_exhaustive]
pub struct PerformanceTarget { pub party_investigations_per_period_hint: i64, /* private fields */ }
PerformanceTarget gives hints on how to evaluate the performance of a model.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
party_investigations_per_period_hint: i64

Required. A number that gives the tuner a hint on the number of parties from this data that will be investigated per period (monthly). This is used to control how the model is evaluated. For example, when trying AML AI for the first time, we recommend setting this to the number of parties investigated in an average month, based on alerts from your existing automated alerting system.

Implementations

Source

impl PerformanceTarget

pub fn new() -> Self

Creates a new default instance.

pub fn set_party_investigations_per_period_hint<T: Into<i64>>( self, v: T, ) -> Self

Sets the value of party_investigations_per_period_hint.

Example
let x = PerformanceTarget::new().set_party_investigations_per_period_hint(42);