BigQueryDestination

Struct BigQueryDestination 

#[non_exhaustive]
pub struct BigQueryDestination { pub table_uri: String, pub write_disposition: WriteDisposition, /* private fields */ }
BigQueryDestination is a wrapper for BigQuery output information.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
table_uri: String

Optional. BigQuery URI to a table, must be of the form bq://projectId.bqDatasetId.tableId. Note that the BigQuery dataset must already exist. VPC-SC restrictions apply.

write_disposition: WriteDisposition

Required. Whether or not to overwrite the destination table. By default the table won’t be overwritten and an error will be returned if the table exists and contains data.

Implementations

Source

impl BigQueryDestination

pub fn new() -> Self

Creates a new default instance.

pub fn set_table_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of table_uri.

Example
let x = BigQueryDestination::new().set_table_uri("example");
pub fn set_write_disposition<T: Into<WriteDisposition>>(self, v: T) -> Self

Sets the value of write_disposition.

Example
use google_cloud_financialservices_v1::model::big_query_destination::WriteDisposition;
let x0 = BigQueryDestination::new().set_write_disposition(WriteDisposition::WriteEmpty);
let x1 = BigQueryDestination::new().set_write_disposition(WriteDisposition::WriteTruncate);