#[non_exhaustive]pub struct CreateEngineConfigRequest {
pub parent: String,
pub engine_config_id: String,
pub engine_config: Option<EngineConfig>,
pub request_id: String,
/* private fields */
}Expand description
Request for creating an EngineConfig resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent of the EngineConfig is the Instance.
engine_config_id: StringRequired. The resource id of the EngineConfig
engine_config: Option<EngineConfig>Required. The EngineConfig that will be created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateEngineConfigRequest
impl CreateEngineConfigRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_engine_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_engine_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of engine_config_id.
Example
let x = CreateEngineConfigRequest::new().set_engine_config_id("example");Sourcepub fn set_engine_config<T>(self, v: T) -> Selfwhere
T: Into<EngineConfig>,
pub fn set_engine_config<T>(self, v: T) -> Selfwhere
T: Into<EngineConfig>,
Sets the value of engine_config.
Example
use google_cloud_financialservices_v1::model::EngineConfig;
let x = CreateEngineConfigRequest::new().set_engine_config(EngineConfig::default()/* use setters */);Sourcepub fn set_or_clear_engine_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<EngineConfig>,
pub fn set_or_clear_engine_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<EngineConfig>,
Sets or clears the value of engine_config.
Example
use google_cloud_financialservices_v1::model::EngineConfig;
let x = CreateEngineConfigRequest::new().set_or_clear_engine_config(Some(EngineConfig::default()/* use setters */));
let x = CreateEngineConfigRequest::new().set_or_clear_engine_config(None::<EngineConfig>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateEngineConfigRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateEngineConfigRequest
impl Clone for CreateEngineConfigRequest
Sourcefn clone(&self) -> CreateEngineConfigRequest
fn clone(&self) -> CreateEngineConfigRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateEngineConfigRequest
impl Debug for CreateEngineConfigRequest
Sourceimpl Default for CreateEngineConfigRequest
impl Default for CreateEngineConfigRequest
Sourcefn default() -> CreateEngineConfigRequest
fn default() -> CreateEngineConfigRequest
Sourceimpl Message for CreateEngineConfigRequest
impl Message for CreateEngineConfigRequest
Sourceimpl PartialEq for CreateEngineConfigRequest
impl PartialEq for CreateEngineConfigRequest
Sourcefn eq(&self, other: &CreateEngineConfigRequest) -> bool
fn eq(&self, other: &CreateEngineConfigRequest) -> bool
self and other values to be equal, and is used by ==.