#[non_exhaustive]pub struct CreateModelRequest {
pub parent: String,
pub model_id: String,
pub model: Option<Model>,
pub request_id: String,
/* private fields */
}Expand description
Request for creating a Model resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent of the Model is the Instance.
model_id: StringRequired. The resource id of the Model
model: Option<Model>Required. The Model that will be created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateModelRequest
impl CreateModelRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_model_id<T: Into<String>>(self, v: T) -> Self
pub fn set_model_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_model<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_model<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateModelRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateModelRequest
impl Clone for CreateModelRequest
Sourcefn clone(&self) -> CreateModelRequest
fn clone(&self) -> CreateModelRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateModelRequest
impl Debug for CreateModelRequest
Sourceimpl Default for CreateModelRequest
impl Default for CreateModelRequest
Sourcefn default() -> CreateModelRequest
fn default() -> CreateModelRequest
Sourceimpl Message for CreateModelRequest
impl Message for CreateModelRequest
Sourceimpl PartialEq for CreateModelRequest
impl PartialEq for CreateModelRequest
Sourcefn eq(&self, other: &CreateModelRequest) -> bool
fn eq(&self, other: &CreateModelRequest) -> bool
self and other values to be equal, and is used by ==.