#[non_exhaustive]pub struct EngineConfig {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub state: State,
pub engine_version: String,
pub tuning: Option<Tuning>,
pub performance_target: Option<PerformanceTarget>,
pub line_of_business: LineOfBusiness,
pub hyperparameter_source_type: HyperparameterSourceType,
pub hyperparameter_source: Option<HyperparameterSource>,
/* private fields */
}Expand description
The EngineConfig resource creates the configuration for training a model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the EngineConfig.
format:
/projects/{project_num}/locations/{location}/instances/{instance}/engineConfigs/{engine_config}
create_time: Option<Timestamp>Output only. The timestamp of creation of this resource.
update_time: Option<Timestamp>Output only. The timestamp of the most recent update of this resource.
labels: HashMap<String, String>Labels
state: StateOutput only. State of the EngineConfig (creating, active, deleting, etc.)
engine_version: StringRequired. The resource name of the EngineVersion used in this model tuning.
format:
/projects/{project_num}/locations/{location}/instances/{instance}/engineVersions/{engine_version}
tuning: Option<Tuning>Optional. Configuration for tuning in creation of the EngineConfig.
This field is required if hyperparameter_source.type is not INHERITED,
and output-only otherwise.
performance_target: Option<PerformanceTarget>Optional. PerformanceTarget gives information on how the tuning and
training will be evaluated. This field is required if
hyperparameter_source.type is not INHERITED, and output-only otherwise.
line_of_business: LineOfBusinessOutput only. The line of business (Retail/Commercial) this engine config is used for. Determined by EngineVersion, cannot be set by user.
hyperparameter_source_type: HyperparameterSourceTypeOptional. The origin of hyperparameters for the created EngineConfig. The
default is TUNING. In this case, the hyperparameters are selected as a
result of a
tuning run.
hyperparameter_source: Option<HyperparameterSource>Optional. Configuration of hyperparameters source EngineConfig.
Implementations
Sourceimpl EngineConfig
impl EngineConfig
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EngineConfig::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EngineConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EngineConfig::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = EngineConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = EngineConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = EngineConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_engine_version<T: Into<String>>(self, v: T) -> Self
pub fn set_engine_version<T: Into<String>>(self, v: T) -> Self
Sets the value of engine_version.
Example
let x = EngineConfig::new().set_engine_version(format!("projects/{project_num_id}/locations/{location_id}/instances/{instance_id}/engineVersions/{engine_version_id}"));Sourcepub fn set_tuning<T>(self, v: T) -> Self
pub fn set_tuning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_tuning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_tuning<T>(self, v: Option<T>) -> Self
Sourcepub fn set_performance_target<T>(self, v: T) -> Selfwhere
T: Into<PerformanceTarget>,
pub fn set_performance_target<T>(self, v: T) -> Selfwhere
T: Into<PerformanceTarget>,
Sets the value of performance_target.
Example
use google_cloud_financialservices_v1::model::engine_config::PerformanceTarget;
let x = EngineConfig::new().set_performance_target(PerformanceTarget::default()/* use setters */);Sourcepub fn set_or_clear_performance_target<T>(self, v: Option<T>) -> Selfwhere
T: Into<PerformanceTarget>,
pub fn set_or_clear_performance_target<T>(self, v: Option<T>) -> Selfwhere
T: Into<PerformanceTarget>,
Sets or clears the value of performance_target.
Example
use google_cloud_financialservices_v1::model::engine_config::PerformanceTarget;
let x = EngineConfig::new().set_or_clear_performance_target(Some(PerformanceTarget::default()/* use setters */));
let x = EngineConfig::new().set_or_clear_performance_target(None::<PerformanceTarget>);Sourcepub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
pub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
Sets the value of line_of_business.
Example
use google_cloud_financialservices_v1::model::LineOfBusiness;
let x0 = EngineConfig::new().set_line_of_business(LineOfBusiness::Commercial);
let x1 = EngineConfig::new().set_line_of_business(LineOfBusiness::Retail);Sourcepub fn set_hyperparameter_source_type<T: Into<HyperparameterSourceType>>(
self,
v: T,
) -> Self
pub fn set_hyperparameter_source_type<T: Into<HyperparameterSourceType>>( self, v: T, ) -> Self
Sets the value of hyperparameter_source_type.
Example
use google_cloud_financialservices_v1::model::engine_config::HyperparameterSourceType;
let x0 = EngineConfig::new().set_hyperparameter_source_type(HyperparameterSourceType::Tuning);
let x1 = EngineConfig::new().set_hyperparameter_source_type(HyperparameterSourceType::Inherited);Sourcepub fn set_hyperparameter_source<T>(self, v: T) -> Selfwhere
T: Into<HyperparameterSource>,
pub fn set_hyperparameter_source<T>(self, v: T) -> Selfwhere
T: Into<HyperparameterSource>,
Sets the value of hyperparameter_source.
Example
use google_cloud_financialservices_v1::model::engine_config::HyperparameterSource;
let x = EngineConfig::new().set_hyperparameter_source(HyperparameterSource::default()/* use setters */);Sourcepub fn set_or_clear_hyperparameter_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<HyperparameterSource>,
pub fn set_or_clear_hyperparameter_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<HyperparameterSource>,
Sets or clears the value of hyperparameter_source.
Example
use google_cloud_financialservices_v1::model::engine_config::HyperparameterSource;
let x = EngineConfig::new().set_or_clear_hyperparameter_source(Some(HyperparameterSource::default()/* use setters */));
let x = EngineConfig::new().set_or_clear_hyperparameter_source(None::<HyperparameterSource>);Trait Implementations
Sourceimpl Clone for EngineConfig
impl Clone for EngineConfig
Sourcefn clone(&self) -> EngineConfig
fn clone(&self) -> EngineConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EngineConfig
impl Debug for EngineConfig
Sourceimpl Default for EngineConfig
impl Default for EngineConfig
Sourcefn default() -> EngineConfig
fn default() -> EngineConfig
Sourceimpl Message for EngineConfig
impl Message for EngineConfig
Sourceimpl PartialEq for EngineConfig
impl PartialEq for EngineConfig
Sourcefn eq(&self, other: &EngineConfig) -> bool
fn eq(&self, other: &EngineConfig) -> bool
self and other values to be equal, and is used by ==.