#[non_exhaustive]pub struct EngineVersion {
pub name: String,
pub state: State,
pub expected_limitation_start_time: Option<Timestamp>,
pub expected_decommission_time: Option<Timestamp>,
pub line_of_business: LineOfBusiness,
/* private fields */
}Expand description
EngineVersion controls which version of the engine is used to tune, train, and run the model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The resource name of the EngineVersion
format:
/projects/{project_num}/locations/{location}/instances/{instance}/engineVersions/{engine_version}
state: StateOutput only. The state of the version.
expected_limitation_start_time: Option<Timestamp>Output only. Planned time to stop allowing training/tuning using this version. Existing trained models can still be used for prediction/backtest.
expected_decommission_time: Option<Timestamp>Output only. Planned time to stop supporting the version, in addition to no training or tuning, models trained on this version can no longer be used for prediction/backtest.
line_of_business: LineOfBusinessOutput only. The line of business (Retail/Commercial) this engine version is used for.
Implementations
Sourceimpl EngineVersion
impl EngineVersion
Sourcepub fn set_expected_limitation_start_time<T>(self, v: T) -> Self
pub fn set_expected_limitation_start_time<T>(self, v: T) -> Self
Sets the value of expected_limitation_start_time.
Example
use wkt::Timestamp;
let x = EngineVersion::new().set_expected_limitation_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_expected_limitation_start_time<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_expected_limitation_start_time<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of expected_limitation_start_time.
Example
use wkt::Timestamp;
let x = EngineVersion::new().set_or_clear_expected_limitation_start_time(Some(Timestamp::default()/* use setters */));
let x = EngineVersion::new().set_or_clear_expected_limitation_start_time(None::<Timestamp>);Sourcepub fn set_expected_decommission_time<T>(self, v: T) -> Self
pub fn set_expected_decommission_time<T>(self, v: T) -> Self
Sets the value of expected_decommission_time.
Example
use wkt::Timestamp;
let x = EngineVersion::new().set_expected_decommission_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_expected_decommission_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expected_decommission_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of expected_decommission_time.
Example
use wkt::Timestamp;
let x = EngineVersion::new().set_or_clear_expected_decommission_time(Some(Timestamp::default()/* use setters */));
let x = EngineVersion::new().set_or_clear_expected_decommission_time(None::<Timestamp>);Sourcepub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
pub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
Sets the value of line_of_business.
Example
use google_cloud_financialservices_v1::model::LineOfBusiness;
let x0 = EngineVersion::new().set_line_of_business(LineOfBusiness::Commercial);
let x1 = EngineVersion::new().set_line_of_business(LineOfBusiness::Retail);Trait Implementations
Sourceimpl Clone for EngineVersion
impl Clone for EngineVersion
Sourcefn clone(&self) -> EngineVersion
fn clone(&self) -> EngineVersion
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EngineVersion
impl Debug for EngineVersion
Sourceimpl Default for EngineVersion
impl Default for EngineVersion
Sourcefn default() -> EngineVersion
fn default() -> EngineVersion
Sourceimpl Message for EngineVersion
impl Message for EngineVersion
Sourceimpl PartialEq for EngineVersion
impl PartialEq for EngineVersion
Sourcefn eq(&self, other: &EngineVersion) -> bool
fn eq(&self, other: &EngineVersion) -> bool
self and other values to be equal, and is used by ==.