#[non_exhaustive]pub struct ExportRegisteredPartiesRequest {
pub name: String,
pub dataset: Option<BigQueryDestination>,
pub line_of_business: LineOfBusiness,
/* private fields */
}Expand description
Request to export a list of currently registered parties.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The full path to the Instance resource in this API.
format: projects/{project}/locations/{location}/instances/{instance}
dataset: Option<BigQueryDestination>Required. The location to output the RegisteredParties.
line_of_business: LineOfBusinessRequired. LineOfBusiness to get RegisteredParties from.
Implementations
Sourceimpl ExportRegisteredPartiesRequest
impl ExportRegisteredPartiesRequest
Sourcepub fn set_dataset<T>(self, v: T) -> Selfwhere
T: Into<BigQueryDestination>,
pub fn set_dataset<T>(self, v: T) -> Selfwhere
T: Into<BigQueryDestination>,
Sourcepub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryDestination>,
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryDestination>,
Sets or clears the value of dataset.
Example
ⓘ
use google_cloud_financialservices_v1::model::BigQueryDestination;
let x = ExportRegisteredPartiesRequest::new().set_or_clear_dataset(Some(BigQueryDestination::default()/* use setters */));
let x = ExportRegisteredPartiesRequest::new().set_or_clear_dataset(None::<BigQueryDestination>);Sourcepub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
pub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self
Sets the value of line_of_business.
Example
ⓘ
use google_cloud_financialservices_v1::model::LineOfBusiness;
let x0 = ExportRegisteredPartiesRequest::new().set_line_of_business(LineOfBusiness::Commercial);
let x1 = ExportRegisteredPartiesRequest::new().set_line_of_business(LineOfBusiness::Retail);Trait Implementations
Sourceimpl Clone for ExportRegisteredPartiesRequest
impl Clone for ExportRegisteredPartiesRequest
Sourcefn clone(&self) -> ExportRegisteredPartiesRequest
fn clone(&self) -> ExportRegisteredPartiesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExportRegisteredPartiesRequest
impl Default for ExportRegisteredPartiesRequest
Sourcefn default() -> ExportRegisteredPartiesRequest
fn default() -> ExportRegisteredPartiesRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ExportRegisteredPartiesRequest
impl PartialEq for ExportRegisteredPartiesRequest
Sourcefn eq(&self, other: &ExportRegisteredPartiesRequest) -> bool
fn eq(&self, other: &ExportRegisteredPartiesRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExportRegisteredPartiesRequest