Instance

Struct Instance 

#[non_exhaustive]
pub struct Instance { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub state: State, pub labels: HashMap<String, String>, pub kms_key: String, /* private fields */ }
Instance is a container for the rest of API resources. Only resources in the same instance can interact with each other. Child resources inherit the location (data residency) and encryption (CMEK). The location of the provided input and output in requests must match the location of the instance.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. The full path to the Instance resource in this API. format: projects/{project}/locations/{location}/instances/{instance}

create_time: Option<Timestamp>

Output only. Timestamp when the Instance was created. Assigned by the server.

update_time: Option<Timestamp>

Output only. Timestamp when the Instance was last updated. Assigned by the server.

state: State

Output only. State of the instance. Assigned by the server.

labels: HashMap<String, String>

Labels

kms_key: String

Required. The KMS key name used for CMEK (encryption-at-rest). format: projects/{project}/locations/{location}/keyRings/{keyRing}/cryptoKeys/{cryptoKey} VPC-SC restrictions apply.

Implementations

Source

impl Instance

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Instance::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"));
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_financialservices_v1::model::instance::State;
let x0 = Instance::new().set_state(State::Creating);
let x1 = Instance::new().set_state(State::Active);
let x2 = Instance::new().set_state(State::Updating);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Instance::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self

Sets the value of kms_key.

Example
let x = Instance::new().set_kms_key("example");