ListModelsRequest

Struct ListModelsRequest 

#[non_exhaustive]
pub struct ListModelsRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub filter: String, pub order_by: String, /* private fields */ }
Request for retrieving a paginated list of Model resources that meet the specified criteria.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent of the Model is the Instance.

page_size: i32

The number of resources to be included in the response. The response contains a next_page_token, which can be used to retrieve the next page of resources.

page_token: String

In case of paginated results, this is the token that was returned in the previous ListModelsResponse. It should be copied here to retrieve the next page of resources. Empty will give the first page of ListModelsRequest, and the last page will return an empty page_token.

filter: String

Specify a filter to narrow search results.

order_by: String

Specify a field to use for ordering.

Implementations

Source

impl ListModelsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListModelsRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"));
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListModelsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListModelsRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListModelsRequest::new().set_filter("example");
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
let x = ListModelsRequest::new().set_order_by("example");