#[non_exhaustive]pub struct ListModelsResponse {
pub models: Vec<Model>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for retrieving a list of Models
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.models: Vec<Model>List of Model resources
next_page_token: StringThis token should be passed to the next ListModelsRequest to retrieve the next page of Models (empty indicicates we are done).
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListModelsResponse
impl ListModelsResponse
Sourcepub fn set_models<T, V>(self, v: T) -> Self
pub fn set_models<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListModelsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListModelsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListModelsResponse
impl Clone for ListModelsResponse
Sourcefn clone(&self) -> ListModelsResponse
fn clone(&self) -> ListModelsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListModelsResponse
impl Debug for ListModelsResponse
Sourceimpl Default for ListModelsResponse
impl Default for ListModelsResponse
Sourcefn default() -> ListModelsResponse
fn default() -> ListModelsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListModelsResponse
impl Message for ListModelsResponse
Sourceimpl PartialEq for ListModelsResponse
impl PartialEq for ListModelsResponse
Sourcefn eq(&self, other: &ListModelsResponse) -> bool
fn eq(&self, other: &ListModelsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListModelsResponse