Model

Struct Model 

#[non_exhaustive]
pub struct Model { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub state: State, pub engine_version: String, pub engine_config: String, pub primary_dataset: String, pub end_time: Option<Timestamp>, pub line_of_business: LineOfBusiness, /* private fields */ }
Model represents a trained model.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. The resource name of the Model. format: /projects/{project_num}/locations/{location}/instances/{instance}/models/{model}

create_time: Option<Timestamp>

Output only. The timestamp of creation of this resource.

update_time: Option<Timestamp>

Output only. The timestamp of the most recent update of this resource.

labels: HashMap<String, String>

Labels

state: State

Output only. State of the model (creating, active, deleting, etc.)

engine_version: String

Output only. The EngineVersion used in training this model. This is output only, and is determined from the EngineConfig used.

engine_config: String

Required. The resource name of the EngineConfig the model training will be based on. Format: /projects/{project_num}/locations/{location}/instances/{instance}/engineConfigs/{engineConfig}

primary_dataset: String

Required. The resource name of the Primary Dataset used in this model training. For information about how primary and auxiliary datasets are used, refer to the engine version’s documentation. Format: /projects/{project_num}/locations/{location}/instances/{instance}/datasets/{dataset}

end_time: Option<Timestamp>

Required. End_time specifies the latest time from which labels are used and from which data is used to generate features for training. End_time should be no later than the end of the date_range of the dataset.

line_of_business: LineOfBusiness

Output only. The line of business (Retail/Commercial) this model is used for. Determined by EngineConfig, cannot be set by user.

Implementations

Source

impl Model

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Model::new().set_name(format!("projects/{project_num_id}/locations/{location_id}/instances/{instance_id}/models/{model_id}"));
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Model::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Model::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Model::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Model::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Model::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Model::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Model::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_financialservices_v1::model::model::State;
let x0 = Model::new().set_state(State::Creating);
let x1 = Model::new().set_state(State::Active);
let x2 = Model::new().set_state(State::Updating);
pub fn set_engine_version<T: Into<String>>(self, v: T) -> Self

Sets the value of engine_version.

Example
let x = Model::new().set_engine_version(format!("projects/{project_num_id}/locations/{location_id}/instances/{instance_id}/engineVersions/{engine_version_id}"));
pub fn set_engine_config<T: Into<String>>(self, v: T) -> Self

Sets the value of engine_config.

Example
let x = Model::new().set_engine_config(format!("projects/{project_num_id}/locations/{location_id}/instances/{instance_id}/engineConfigs/{engine_config_id}"));
pub fn set_primary_dataset<T: Into<String>>(self, v: T) -> Self

Sets the value of primary_dataset.

Example
let x = Model::new().set_primary_dataset(format!("projects/{project_num_id}/locations/{location_id}/instances/{instance_id}/datasets/{dataset_id}"));
pub fn set_end_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of end_time.

Example
use wkt::Timestamp;
let x = Model::new().set_end_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of end_time.

Example
use wkt::Timestamp;
let x = Model::new().set_or_clear_end_time(Some(Timestamp::default()/* use setters */));
let x = Model::new().set_or_clear_end_time(None::<Timestamp>);
pub fn set_line_of_business<T: Into<LineOfBusiness>>(self, v: T) -> Self

Sets the value of line_of_business.

Example
use google_cloud_financialservices_v1::model::LineOfBusiness;
let x0 = Model::new().set_line_of_business(LineOfBusiness::Commercial);
let x1 = Model::new().set_line_of_business(LineOfBusiness::Retail);