#[non_exhaustive]pub struct PerformanceTarget {
pub party_investigations_per_period_hint: i64,
/* private fields */
}Expand description
PerformanceTarget gives hints on how to evaluate the performance of a model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.party_investigations_per_period_hint: i64Required. A number that gives the tuner a hint on the number of parties from this data that will be investigated per period (monthly). This is used to control how the model is evaluated. For example, when trying AML AI for the first time, we recommend setting this to the number of parties investigated in an average month, based on alerts from your existing automated alerting system.
Implementations
Sourceimpl PerformanceTarget
impl PerformanceTarget
Sourcepub fn set_party_investigations_per_period_hint<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_party_investigations_per_period_hint<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of party_investigations_per_period_hint.
Example
ⓘ
let x = PerformanceTarget::new().set_party_investigations_per_period_hint(42);Trait Implementations
Sourceimpl Clone for PerformanceTarget
impl Clone for PerformanceTarget
Sourcefn clone(&self) -> PerformanceTarget
fn clone(&self) -> PerformanceTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PerformanceTarget
impl Debug for PerformanceTarget
Sourceimpl Default for PerformanceTarget
impl Default for PerformanceTarget
Sourcefn default() -> PerformanceTarget
fn default() -> PerformanceTarget
Returns the “default value” for a type. Read more
Sourceimpl Message for PerformanceTarget
impl Message for PerformanceTarget
Sourceimpl PartialEq for PerformanceTarget
impl PartialEq for PerformanceTarget
Sourcefn eq(&self, other: &PerformanceTarget) -> bool
fn eq(&self, other: &PerformanceTarget) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PerformanceTarget