#[non_exhaustive]pub struct BigQueryDestination {
pub table_uri: String,
pub write_disposition: WriteDisposition,
/* private fields */
}Expand description
BigQueryDestination is a wrapper for BigQuery output information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_uri: StringOptional. BigQuery URI to a table, must be of the form bq://projectId.bqDatasetId.tableId. Note that the BigQuery dataset must already exist. VPC-SC restrictions apply.
write_disposition: WriteDispositionRequired. Whether or not to overwrite the destination table. By default the table won’t be overwritten and an error will be returned if the table exists and contains data.
Implementations
Sourceimpl BigQueryDestination
impl BigQueryDestination
Sourcepub fn set_table_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_table_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_write_disposition<T: Into<WriteDisposition>>(self, v: T) -> Self
pub fn set_write_disposition<T: Into<WriteDisposition>>(self, v: T) -> Self
Sets the value of write_disposition.
Example
ⓘ
use google_cloud_financialservices_v1::model::big_query_destination::WriteDisposition;
let x0 = BigQueryDestination::new().set_write_disposition(WriteDisposition::WriteEmpty);
let x1 = BigQueryDestination::new().set_write_disposition(WriteDisposition::WriteTruncate);Trait Implementations
Sourceimpl Clone for BigQueryDestination
impl Clone for BigQueryDestination
Sourcefn clone(&self) -> BigQueryDestination
fn clone(&self) -> BigQueryDestination
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BigQueryDestination
impl Debug for BigQueryDestination
Sourceimpl Default for BigQueryDestination
impl Default for BigQueryDestination
Sourcefn default() -> BigQueryDestination
fn default() -> BigQueryDestination
Returns the “default value” for a type. Read more
Sourceimpl Message for BigQueryDestination
impl Message for BigQueryDestination
Sourceimpl PartialEq for BigQueryDestination
impl PartialEq for BigQueryDestination
Sourcefn eq(&self, other: &BigQueryDestination) -> bool
fn eq(&self, other: &BigQueryDestination) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BigQueryDestination